@@ -6,15 +6,12 @@
 #.##......##..##....##....##..##..##..##..##......##..........##.#
 #.##......##..##....##....##..##...####...######..######...####..#
 #................................................................#
-
+#                                                                #
 # PlanetaRY spanGLES                                             #
 #                                                                #
 ##################################################################
 # License http://github.com/seap-udea/pryngles-public            #
 ##################################################################
-# Main contributors:                                             #
-#   Jorge I. Zuluaga, Mario Sucerquia, Jaime A. Alvarado         #
-##################################################################
 
 
 #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -169,24 +166,25 @@ class PrynglesCommon(object):
 
 from pryngles.version import *
 
-#Utility modules
+#Constants
 from pryngles.consts import *
+
+#Utility modules
 from pryngles.misc import *
+from pryngles.extensions import *
 from pryngles.science import *
+from pryngles.plot import *
+from pryngles.orbit import *
+from pryngles.scatterer import *
 
 #Legacy module
 from pryngles.legacy import *
 
-#General modules
-from pryngles.plot import *
-from pryngles.orbit import *
-
 #Core modules
 from pryngles.sampler import *
 from pryngles.spangler import *
 from pryngles.body import *
 from pryngles.system import *
-from pryngles.optics import *
 
 #Reset verbosity
 Verbose.VERBOSITY=VERB_NONE
