@@ -6,15 +6,12 @@
 #.##......##..##....##....##..##..##..##..##......##..........##.#
 #.##......##..##....##....##..##...####...######..######...####..#
 #................................................................#
-
+#                                                                #
 # PlanetaRY spanGLES                                             #
 #                                                                #
 ##################################################################
 # License http://github.com/seap-udea/pryngles-public            #
 ##################################################################
-# Main contributors:                                             #
-#   Jorge I. Zuluaga, Mario Sucerquia, Jaime A. Alvarado         #
-##################################################################
 
 #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 # External required packages
@@ -86,12 +83,21 @@ RAD=Consts.rad
 DEG=Consts.deg
 
 #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-# Constants of module $science
+# Constants of module extensions
+#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+import ctypes
+DOUBLE = ctypes.c_double
+PDOUBLE = ctypes.POINTER(DOUBLE)
+PPDOUBLE = ctypes.POINTER(PDOUBLE)
+PPPDOUBLE = ctypes.POINTER(PPDOUBLE)
+
+#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+# Constants of module science
 #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 SCIENCE_LIMB_NORMALIZATIONS=dict()
 
 #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-# Constants of module $orbit
+# Constants of module orbit
 #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 REBOUND_ORBITAL_PROPERTIES=dict(
     #Mass
@@ -108,8 +114,13 @@ REBOUND_ORBITAL_PROPERTIES=dict(
     theta=0,l=0,
 )
 
+REBOUND_CARTESIAN_PROPERTIES=dict(
+    #Cartesian coordinates
+    x=0,y=0,z=0,vx=0,vy=0,vz=0,    
+)
+
 #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-# Constants of module $sampler
+# Constants of module sampler
 #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 """ Sampler presets are the values of N 
     for which there are already stored samples
@@ -141,7 +152,7 @@ SAMPLE_SHAPES+=["ring"]
 SAMPLE_SHAPES+=["sphere"]
 
 #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-# Constants of module $spangler
+# Constants of module spangler
 #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 """
     Colors: Given in hue (0-360), level (0: black-1: white), saturation (0-1)
@@ -259,6 +270,8 @@ SPANGLER_COLUMNS=odict({
     "z_cen_obs":0.0, #z-coordinate of the center of the body to which the spangle belows
     "hidden_by_obs":"", #Which body intersect the observer or light coming to a Spangle
     "transit_over_obs":"", #Which body is intersected by the Spangle (is transiting over)
+    "beta_loc":0, #Beta angle rotates the local scattering plane to the planetary scattering plane
+    
     
     #Coordinates of the spangle (cartesian and spherical) in the light-source system
     "center_luz":[0,0,0],#Center of the body
@@ -275,18 +288,23 @@ SPANGLER_COLUMNS=odict({
     "transit_over_luz":"", #Which body is intersected by the Spangle (is transiting over)
     
     #Azimutal angles
-    "azim_obs_luz":0,#Difference between the azimuth of the light-source and the observer over the spangle
+    "azim_obs_luz":0,#Difference between the azimuth of the observer over the spangle and that of light-source
 
     #Geometrical parameters
     "asp":1.0, #Effective area of the spangle in 3D 
     "dsp":1.0, #Effective diameter of spangle, dsp = 2*(asp/pi)**0.5
 
     #Optical parameters
+    "scatterer":"",#Hash (identifier) of the scatterer used for this spangle
     "albedo_gray_normal":1.0,#Wavelength-independent normal albedo
     "albedo_gray_spherical":1.0,#Wavelength-independent spherical albedo
     "tau_gray_optical":0.0,#Wavelength-independent optical depth
     
+    #Polarization parameters
+    "F":0,"Q":0,"U":0,"V":0,"P":0, #Stokes vector components
+    
     #Thermal characteristics
+    "emmitter":"",#Hash (identifier) of the emmitter used for this spangle
     "Teq":273.15,#K, equilibrium temperature
     "Tem":273.15,#K, emmision temperature
     "emmisivity":1,#1 perfect black body
@@ -321,12 +339,13 @@ SPANGLER_KEY_ORDERING=[
     #Coordinates
     'x_ecl', 'y_ecl', 'z_ecl', 'ns_ecl',
     #Orientation
-    'azim_obs', 'n_obs', 'd_obs', 'asp_obs', 'cos_obs', 'hidden_by_obs', 'transit_over_obs', 
+    'azim_obs', 'n_obs', 'd_obs', 'asp_obs', 'cos_obs', 'hidden_by_obs', 'transit_over_obs', 'beta_loc',
     'azim_luz', 'n_luz', 'd_luz', 'asp_luz', 'cos_luz', 'hidden_by_luz', 'transit_over_luz',
     #Geometrical bulk properties
     'asp', 
     #Physical bulk properties
     'albedo_gray_normal', 'albedo_gray_spherical', 'tau_gray_optical', 
+    'F','Q','U','V','P',
     'Teq', 'Tem', 'emmisivity', 
     #State
     'visible', 'shadow', 'indirect', 'emit', 
@@ -368,6 +387,9 @@ SPANGLER_KEY_ORDERING=[
     
     'dsp', 
     
+    #Other
+    'scatterer', 'emmitter',
+    
     #Internal states
     'unset', 'hidden', 'source', 'intersect', 'above', 
     ]
@@ -480,7 +502,10 @@ SPANGLER_COLUMNS=odict({
     "asp_int":1.0, #Effective area of the spangle with respect to intersection perspective 
     "z_cen_int":0.0, #z-coordinate of the center of the body to which the spangle belows
     "hidden_by_int":"", #Which body intersect the observer or light coming to a Spangle
+    "transit_over_int":"", #Which body is intersected by the Spangle (is transiting over)
 
+    "string_int":"",#Temporal string
+    
     #Coordinates of the spangle (cartesian and spherical) in the observer system
     "center_obs":[0,0,0], #Center of the body
     "x_obs":1,"y_obs":0,"z_obs":0, #Cartesian coordinates of the spangle
@@ -493,6 +518,7 @@ SPANGLER_COLUMNS=odict({
     "asp_obs":1.0, #Effective area of the spangle with respect to observer perspective 
     "z_cen_obs":0.0, #z-coordinate of the center of the body to which the spangle belows
     "hidden_by_obs":"", #Which body intersect the observer or light coming to a Spangle
+    "transit_over_obs":"", #Which body is intersected by the Spangle (is transiting over)
     
     #Coordinates of the spangle (cartesian and spherical) in the light-source system
     "center_luz":[0,0,0],#Center of the body
@@ -506,21 +532,23 @@ SPANGLER_COLUMNS=odict({
     "asp_luz":1, #Effective area of the spangle with respect to light-source perspective 
     "z_cen_luz":0.0, #z-coordinate of the center of the body to which the spangle belows
     "hidden_by_luz":"", #Which body intersect the observer or light coming to a Spangle
-    "rho_transit":0, #Distance from the spangle to the center of the source disk
+    "transit_over_luz":"", #Which body is intersected by the Spangle (is transiting over)
     
     #Azimutal angles
-    "azim_obs_luz":0,#Difference between the azimuth of the light-source and the observer over the spangle
+    "azim_obs_luz":0,#Difference between the azimuth of the observer over the spangle and that of light-source
 
     #Geometrical parameters
     "asp":1.0, #Effective area of the spangle in 3D 
     "dsp":1.0, #Effective diameter of spangle, dsp = 2*(asp/pi)**0.5
 
     #Optical parameters
+    "scatterer":"",#Hash (identifier) of the scatterer used for this spangle
     "albedo_gray_normal":1.0,#Wavelength-independent normal albedo
     "albedo_gray_spherical":1.0,#Wavelength-independent spherical albedo
     "tau_gray_optical":0.0,#Wavelength-independent optical depth
     
     #Thermal characteristics
+    "emmitter":"",#Hash (identifier) of the emmitter used for this spangle
     "Teq":273.15,#K, equilibrium temperature
     "Tem":273.15,#K, emmision temperature
     "emmisivity":1,#1 perfect black body
@@ -550,7 +578,7 @@ SPANGLER_COLUMNS.update(SPANGLER_SOURCE_STATES)
 """
 
 #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-# Constants of module $body
+# Constants of module body
 #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 BODY_KINDS=[]
 
@@ -562,6 +590,7 @@ BODY_DEFAULTS.update(odict(
     
     name=None,
     name_by_kind=False,
+    source=None,
     
     #Orbit
     m=1,
@@ -582,6 +611,10 @@ BODY_DEFAULTS.update(odict(
     seed=0,
     preset=True,
     
+    albedo_gray_spherical=1,
+    albedo_gray_normal=1,
+    tau_gray_optical=0,
+    
     #Legacy
     primary=None,
     optics=dict(),
@@ -599,6 +632,7 @@ STAR_DEFAULTS.update(odict(
 
     #Orbit: update
     #Same as body
+    radius=0.1,
     
     #Physics: update
     #Same as Body
@@ -621,12 +655,11 @@ PLANET_DEFAULTS.update(odict(
     
     #Physics: update
     #Same as Body
+    radius=0.1,
     
     #Optical: update
     spangle_type=SPANGLE_SOLID_ROCK,
     geometry="sphere",
-    
-    albedo_gray_spherical=1,
 ))
 BODY_KINDS+=["Planet"]
 
@@ -638,14 +671,12 @@ RING_DEFAULTS.update(odict(
     
     #Physics: update
     #Same as Body
-    fi=1.0,
+    fi=1.5,
     fe=2.0,
     
     #Optics: update
     spangle_type=SPANGLE_GRANULAR,
     shape="ring",
-    albedo_gray_normal=1,
-    tau_gray_optical=0,
 ))
 
 BODY_KINDS+=["Ring"]
@@ -656,3 +687,30 @@ OBSERVER_DEFAULTS.update(odict(
     beta=0,
 ))
 BODY_KINDS+=["Observer"]
+
+#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+# Constants of module system
+#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+LEGACY_PHYSICAL_PROPERTIES=dict(
+    #Albedos
+    AS=1,AL=1,
+    #Ring geometrical opacity
+    taug=1.0, #Geometrical opacity
+    diffeff=1.0, #Diffraction efficiency
+    #Law of diffuse reflection on ring surface
+    reflection_rings_law=lambda x,y:x,
+    #Observations wavelength
+    wavelength=550e-9,
+    #Ring particle propeties (see French & Nicholson, 2000)
+    particles=dict(q=3,s0=100e-6,smin=1e-2,smax=1e2,Qsc=1,Qext=2),
+    #Stellar limb darkening
+    limb_cs=[],
+)
+
+#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+# Constants of module scatterer
+#%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+try:
+    SCATTERERS_CATALOGUE
+except:
+    SCATTERERS_CATALOGUE=dict()
