@@ -6,15 +6,12 @@
 #.##......##..##....##....##..##..##..##..##......##..........##.#
 #.##......##..##....##....##..##...####...######..######...####..#
 #................................................................#
-
+#                                                                #
 # PlanetaRY spanGLES                                             #
 #                                                                #
 ##################################################################
 # License http://github.com/seap-udea/pryngles-public            #
 ##################################################################
-# Main contributors:                                             #
-#   Jorge I. Zuluaga, Mario Sucerquia, Jaime A. Alvarado         #
-##################################################################
 import unittest
 from pryngles import *
 class Test(unittest.TestCase):
@@ -76,6 +73,8 @@ class Test(unittest.TestCase):
 	    sim.add(m=mm,x=xp+xm,vy=vp+vm)
 	    P=sim.particles[1].P
 	
+	    anim=Plot.animate_rebound(sim,traces=True,nsnap=200,axis=True,ms=1)
+	
 	    anim=Plot.animate_rebound(sim,filename="/tmp/animate-rebound.gif",interval=20)
 	
 	    Verbose.VERBOSITY=VERB_NONE
